==> haskell-fast-logger-3.0.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fast-logger
version:              3.0.1
visibility:           public
id:                   fast-logger-3.0.1-1NmpKAojIz66wrNMf2OJYF
key:                  fast-logger-3.0.1-1NmpKAojIz66wrNMf2OJYF
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system
category:             System
abi:                  8a132b4908dfa210b7edfae6a3334e73
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.IO
    System.Log.FastLogger.FileIO System.Log.FastLogger.LogStr
    System.Log.FastLogger.Logger

import-dirs:          /usr/lib/ghc-8.8.3/site-local/fast-logger-3.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/fast-logger-3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/fast-logger-3.0.1
hs-libraries:         HSfast-logger-3.0.1-1NmpKAojIz66wrNMf2OJYF
depends:
    array-0.5.4.0 auto-update-0.1.6-CCXymisHtH54CL1LCi2wmR
    base-4.13.0.0 bytestring-0.10.10.0 directory-1.3.6.0
    easy-file-0.2.2-J4TKbcvAQyzBUnvhFNRXda filepath-1.4.2.1
    text-1.2.4.0 unix-compat-0.5.2-1FQI6nqgJsoGP4VQqT0w3a
    unix-time-0.4.7-EZUXW0BIPsW19EKBBgy5Q0

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-3.0.1-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fast-logger
version:              3.0.1
visibility:           public
id:                   fast-logger-3.0.1-68oQnigx574IkTZX3Ej20w
key:                  fast-logger-3.0.1-68oQnigx574IkTZX3Ej20w
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system
category:             System
abi:                  419706c728b112c22154d01ce189a828
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.IO
    System.Log.FastLogger.FileIO System.Log.FastLogger.LogStr
    System.Log.FastLogger.Logger

import-dirs:          /usr/lib/ghc-8.10.1/site-local/fast-logger-3.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/fast-logger-3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/fast-logger-3.0.1
hs-libraries:         HSfast-logger-3.0.1-68oQnigx574IkTZX3Ej20w
depends:
    array-0.5.4.0 auto-update-0.1.6-Bb49RoydQAuK4XJhSXshbK
    base-4.14.0.0 bytestring-0.10.10.0 directory-1.3.6.0
    easy-file-0.2.2-5S2ZSC5kFKP3S98aFfdkCp filepath-1.4.2.1
    text-1.2.3.2 unix-compat-0.5.2-LUrHZKGZjHj4senyv026n5
    unix-time-0.4.7-BlryrKJ4hjt8qwVi3FJ7N1

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
